@@ -89,7 +89,7 @@ class Lotus:
     def process_signals(self, ns, start=False):
         for symbol in self.symbols:
             if start:
-                self.order.check_open_bot_order(symbol, entry, stoploss)
+                self.order.check_open_bot_order(symbol, ns[symbol]['entry'], ns[symbol]['stoploss'])
                 time.sleep(3)
             signal = ns[symbol]['signal']
             if signal:
